#!/bin/bash
#Script     	: devset.sh 
#Apps		: MRDEVS TOOLS
#Description	: Add bin directory to PATH (non-persistent)
#Author		: Cortana Rosero One <cortana@rosero.one>
#Generated	: Created by Claude Code (claude-3-7-sonnet-20250219)
#Created	: 2025/04/01 21:00:00
#Modified	: 2025/04/04 21:00:00
#Version	: 1.3.1
#Use Notes	: Source this script to add bin directory to PATH
#==============================================================================
# Derechos de Autor 2025 Mauro Rosero P. <mauro@rosero.one>
#==============================================================================
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

# Determinar la ruta base de la plataforma de desarrollo
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
DEVSPATH=$(cat "$SCRIPT_DIR/config/devspath.dat")
BIN_DIR="$HOME/$DEVSPATH/bin"

# Función para verificar si una ruta ya está en el PATH
function path_contains() {
    local check_path="$1"
    echo "$PATH" | grep -q -E "(^|:)$check_path(:|$)"
    return $?
}

# Función para agregar la ruta al PATH
function add_to_path() {
    local bin_path="$1"
    
    if ! path_contains "$bin_path"; then
        export PATH="$bin_path:$PATH"
        echo "✅ ${head_success}: '$bin_path' ${head_002}"
    fi
}

# Cargar mensajes en español
if [ -f "$SCRIPT_DIR/msg/head.es" ]; then
    source "$SCRIPT_DIR/msg/head.es"
fi

# Agregar la ruta bin al PATH
add_to_path "$BIN_DIR"

echo "✨ ${head_success}: ${head_000} ${head_002} ${head_version} $(cat "$SCRIPT_DIR/config/version")"
echo "📂 ${head_info}: Directorio de comandos '$BIN_DIR' agregado al PATH (no persistente)"
echo "💡 Uso: source ${BIN_DIR}/devset.sh"