#!/bin/bash
#Script     	: ollama.sh
#Apps			: MRDEVS TOOLS
#Description	: Cliente para interactuar con Ollama (IA local)
#Author			: Mauro Rosero Pérez
#Company Email	: mauro@rosero.one
#Personal Email	: mauro.rosero@gmail.com
#Created		: 2024/12/01 15:27:00
#Modified		: 2025/03/19 11:57:08
#Version		: 1.3.0
#==============================================================================
# Derechos de Autor [2025] [Mauro Rosero P. <mauro@rosero.one>]
#==============================================================================
# Este programa es software libre: usted puede redistribuirlo y/o modificarlo
# bajo los términos de la Licencia Pública Affero General de GNU tal como
# lo publica la Free Software Foundation, ya sea la versión 3 de la licencia,
# o (a su elección) cualquier versión posterior.
#
# Este programa se distribuye con la esperanza de que sea útil,
# pero SIN NINGUNA GARANTÍA; sin siquiera la garantía implícita de
# COMERCIABILIDAD o IDONEIDAD PARA UN PROPÓSITO PARTICULAR. Consulte la
# Licencia Pública Affero General de GNU para obtener más detalles.
#
# Debería haber recibido una copia de la Licencia Pública Affero General
# junto con este programa. Si no la recibió, consulte <https://www.gnu.org/licenses/>.

# Configuración inicial
# Usar DEVELOPER_DIR de base.lib
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
BIN_BASE="bin"
BIN_LIBS="lib"
BIN_MESG="msg"
BIN_CFGS="config"

# Leer DEVSPATH desde el archivo de configuración o usar "devs" por defecto
if [ -f "$SCRIPT_DIR/config/devspath.dat" ]; then
  DEVSPATH=$(cat "$SCRIPT_DIR/$BIN_CFGS/devspath.dat")
else
  DEVSPATH="devs"
fi

BIN_HOME="$HOME/$DEVSPATH"
BIN_PATH=$BIN_HOME/$BIN_BASE
VERSION=$(cat "$BIN_HOME/$BIN_BASE/$BIN_CFGS/version")

# CHECK SHELL LANGUAGE
BIN_LANG=${LANG:0:2}

# Importar bibliotecas necesarias
if [ -f "${BIN_HOME}/${BIN_BASE}/${BIN_LIBS}/base.lib" ]; then
  source "${BIN_HOME}/${BIN_BASE}/${BIN_LIBS}/base.lib"
  # Cargar mensajes en el idioma del sistema o español por defecto
  load_messages "${BIN_HOME}/${BIN_BASE}" "${BIN_MESG}" "${BIN_LANG}" "head"
  title="${head_000} ${head_002}"
fi

# Check if we should use podman or docker (prefer podman)
if command -v podman >/dev/null 2>&1; then
  CONTAINER_CMD="podman"
elif command -v docker >/dev/null 2>&1; then
  CONTAINER_CMD="docker"
else
  echo "Error: Neither podman nor docker is installed"
  exit 1
fi

# Verificar si el contenedor Ollama está en ejecución
if ${CONTAINER_CMD} ps | grep -q "ollama"; then
  # Si está en ejecución, ejecutar el comando pasado como argumento
  ${CONTAINER_CMD} exec -it ollama ollama "$@"
else
  echo "El servicio Ollama no está en ejecución. Iniciándolo..."
  "${BIN_PATH}/ollama_up.sh"
  
  # Esperar un momento para que el servicio esté listo
  echo "Esperando a que el servicio esté listo..."
  sleep 5
  
  # Verificar nuevamente si el contenedor está en ejecución
  if ${CONTAINER_CMD} ps | grep -q "ollama"; then
    ${CONTAINER_CMD} exec -it ollama ollama "$@"
  else
    echo "Error: No se pudo iniciar el servicio Ollama correctamente."
    exit 1
  fi
fi
